@@ -2,6 +2,7 @@ use super::{pat::PatType, *};
 use crate::error::SyntaxError;
 use swc_atoms::js_word;
 use swc_common::Spanned;
+use typed_arena::Arena;
 
 mod module_item;
 
@@ -20,7 +21,7 @@ impl<'a, I: Tokens> Parser<I> {
 
         let old_ctx = self.ctx();
 
-        let mut stmts = Vec::with_capacity(16);
+        let stmts = Arena::new();
         while {
             let c = cur!(self, false).ok();
             c != end
@@ -45,7 +46,7 @@ impl<'a, I: Tokens> Parser<I> {
                 }
             }
 
-            stmts.push(stmt);
+            stmts.alloc(stmt);
         }
 
         if end.is_some() {
@@ -54,7 +55,7 @@ impl<'a, I: Tokens> Parser<I> {
 
         self.set_ctx(old_ctx);
 
-        Ok(stmts)
+        Ok(stmts.into_vec())
     }
 
     pub fn parse_stmt(&mut self, top_level: bool) -> PResult<Stmt> {
@@ -1136,6 +1137,15 @@ pub(super) trait IsDirective {
     }
 }
 
+impl<T> IsDirective for Box<T>
+where
+    T: IsDirective,
+{
+    fn as_ref(&self) -> Option<&Stmt> {
+        T::as_ref(&**self)
+    }
+}
+
 impl IsDirective for Stmt {
     fn as_ref(&self) -> Option<&Stmt> {
         Some(self)
@@ -1150,6 +1160,20 @@ pub(super) trait StmtLikeParser<'a, Type: IsDirective> {
     ) -> PResult<Type>;
 }
 
+impl<'a, I: Tokens, T> StmtLikeParser<'a, Box<T>> for Parser<I>
+where
+    T: IsDirective,
+    Self: StmtLikeParser<'a, T>,
+{
+    fn handle_import_export(
+        &mut self,
+        top_level: bool,
+        decorators: Vec<Decorator>,
+    ) -> PResult<Box<T>> {
+        <Self as StmtLikeParser<T>>::handle_import_export(self, top_level, decorators).map(Box::new)
+    }
+}
+
 impl<'a, I: Tokens> StmtLikeParser<'a, Stmt> for Parser<I> {
     fn handle_import_export(&mut self, top_level: bool, _: Vec<Decorator>) -> PResult<Stmt> {
         let start = cur_pos!(self);
